import { BrowserRouter as Router, Routes, Route } from 'react-router-dom';
import { QueryClientProvider } from '@tanstack/react-query';
import { lazy, Suspense, useEffect } from 'react';
import { Toaster } from '@/components/ui/sonner';
import { queryClient } from '@/config/queryClient';
import ErrorBoundary from '@/components/common/ErrorBoundary';
import LoadingFallback from '@/components/common/LoadingFallback';
import BreadcrumbSchema from '@/components/BreadcrumbSchema';
import { storeHealthCheck } from '@/utils/healthCheck';
import { usePagePerformance } from '@/hooks/useAnalytics';
import { AnalyticsWrapper } from '@/components/AnalyticsWrapper';

// Import Index directly for fastest initial load
import Index from './pages/Index';

// Lazy load individual pages for better performance
const About = lazy(() => import('./pages/About'));
const Services = lazy(() => import('./pages/Services'));
const Contact = lazy(() => import('./pages/Contact'));
const Resources = lazy(() => import('./pages/Resources'));
const FAQ = lazy(() => import('./pages/FAQ'));
const Blog = lazy(() => import('./pages/Blog'));
const BlogPost = lazy(() => import('./pages/BlogPost'));
const AuthorBio = lazy(() => import('./pages/AuthorBio'));
const BankStatementLoans = lazy(() => import('./pages/BankStatementLoans'));
const DSCRLoans = lazy(() => import('./pages/DSCRLoans'));
const ThankYou = lazy(() => import('./pages/ThankYou'));
const PrivacyPolicy = lazy(() => import('./pages/PrivacyPolicy'));
const NotFound = lazy(() => import('./pages/NotFound'));
const Sitemap = lazy(() => import('./pages/Sitemap'));
const Maxdomain = lazy(() => import('./pages/Maxdomain'));
const NonQMGlossary = lazy(() => import('./pages/NonQMGlossary'));
const CodeViewer = lazy(() => import('./pages/CodeViewer'));

function App() {
  // Initialize analytics tracking
  usePagePerformance();

  useEffect(() => {
    // Perform health check on app mount
    if (import.meta.env.PROD) {
      setTimeout(storeHealthCheck, 1000);
    }
  }, []);

  return (
    <ErrorBoundary>
      <QueryClientProvider client={queryClient}>
        <Router>
          <AnalyticsWrapper>
            <BreadcrumbSchema />
            <Routes>
              <Route path="/" element={<Index />} />
              <Route path="/about" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <About />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/services" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <Services />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/contact" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <Contact />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/resources" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <Resources />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/faq" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <FAQ />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/blog" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <Blog />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/blog/:slug" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <BlogPost />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/blog/author/:authorId" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <AuthorBio />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/bank-statement-loans" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <BankStatementLoans />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/dscr-loans" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <DSCRLoans />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/maxdomain" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <Maxdomain />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/thankyou" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <ThankYou />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/privacy-policy" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <PrivacyPolicy />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/sitemap" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <Sitemap />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/non-qm-glossary" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <NonQMGlossary />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="/code-viewer" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <CodeViewer />
                  </Suspense>
                </ErrorBoundary>
              } />
              <Route path="*" element={
                <ErrorBoundary>
                  <Suspense fallback={<LoadingFallback />}>
                    <NotFound />
                  </Suspense>
                </ErrorBoundary>
              } />
            </Routes>
            <Toaster />
          </AnalyticsWrapper>
        </Router>
      </QueryClientProvider>
    </ErrorBoundary>
  );
}

export default App;
